import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_custom_form_component/widget/field/field.dart';
import 'package:flutter_custom_form_component/widget/field/mixin.dart';

/// Text field supports name format.
class NameFieldWidget extends FieldWidget {
  late final Function(String value)? _onChanged;
  late final String _value;

  NameFieldWidget(
      {TextInputAction action = TextInputAction.next,
      String? hint,
      bool isEnabled = true,
      Key? key,
      Function(String value)? onChanged,
      String value = ''})
      : super(action: action, hint: hint, isEnabled: isEnabled, key: key) {
    _onChanged = onChanged;
    _value = value;
  }

  @override
  State<StatefulWidget> createState() => _State();
}

class _State extends State<NameFieldWidget> with FieldWidgetMixin {
  final TextEditingController _controller = TextEditingController();

  @override
  Widget build(final BuildContext context) {
    _controller.text = widget._value;
    return container(
        textField: TextField(
            controller: _controller,
            decoration: InputDecoration(
                border: InputBorder.none, hintText: widget.hint),
            enabled: widget.isEnabled,
            inputFormatters: [
              FilteringTextInputFormatter.allow(RegExp('[a-z A-Z]'))
            ],
            keyboardType: TextInputType.name,
            textCapitalization: TextCapitalization.words,
            textInputAction: widget.action));
  }

  void _controllerListener() {
    widget._onChanged?.call(_controller.text);
  }

  @override
  void dispose() {
    _controller.removeListener(_controllerListener);
    _controller.dispose();
    super.dispose();
  }

  @override
  void initState() {
    super.initState();
    _controller.addListener(_controllerListener);
  }
}
